@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import datetime
+from typing import Callable
 
 from pip_services3_commons.convert import StringConverter
 
@@ -11,9 +12,9 @@ class HeartBeatOperations(RestOperations):
     def __init__(self):
         super(HeartBeatOperations, self).__init__()
 
-    def get_heart_beat_operation(self):
-        return lambda req, res: self.heartbeat(req, res)
+    def get_heart_beat_operation(self) -> Callable:
+        return lambda: self.heartbeat()
 
-    def heartbeat(self, req=None, res=None):
+    def heartbeat(self) -> str:
         result = StringConverter.to_string(datetime.datetime.now())
         return self._send_result(result)
