@@ -10,9 +10,11 @@
 """
 import datetime
 
+from pip_services3_commons.config import ConfigParams
 from pip_services3_commons.convert import StringConverter
-from pip_services3_commons.refer import Descriptor
+from pip_services3_commons.refer import Descriptor, IReferences
 from pip_services3_commons.run import Parameters
+from pip_services3_components.info import ContextInfo
 
 from .RestService import RestService
 
@@ -63,10 +65,6 @@ class StatusRestService(RestService):
           service.open("123")
           # ...
     """
-    _start_time = datetime.datetime.now()
-    _references2 = None
-    _context_info = None
-    _route = "status"
 
     def __init__(self):
         """
@@ -74,8 +72,12 @@ class StatusRestService(RestService):
         """
         super(StatusRestService, self).__init__()
         self._dependency_resolver.put("context-info", Descriptor("pip-services", "context-info", "default", "*", "1.0"))
+        self.__start_time: datetime.datetime = datetime.datetime.now()
+        self.__references2: IReferences = None
+        self.__context_info: ContextInfo = None
+        self.__route: str = "status"
 
-    def configure(self, config):
+    def configure(self, config: ConfigParams):
         """
         Configures component by passing configuration parameters.
 
@@ -83,46 +85,45 @@ class StatusRestService(RestService):
         """
         super(StatusRestService, self).configure(config)
 
-        self._route = config.get_as_string_with_default("route", self._route)
+        self.__route = config.get_as_string_with_default("route", self.__route)
 
-    def set_references(self, references):
+    def set_references(self, references: IReferences):
         """
         Sets references to dependent components.
 
         :param references: references to locate the component dependencies.
         """
-        self._references2 = references
+        self.__references2 = references
         super(StatusRestService, self).set_references(references)
-        self._context_info = self._dependency_resolver.get_one_optional("context-info")
+        self.__context_info = self._dependency_resolver.get_one_optional("context-info")
 
     def register(self):
         """
         Registers all service routes in HTTP endpoint.
         """
-        # self.register_route("GET", self._route, lambda req, res: self.status(req, res))
-        self.register_route("GET", self._route, None, self.status)
+        # self.register_route("GET", self.__route, lambda req, res: self.status(req, res))
+        self.register_route("GET", self.__route, None, self.status)
 
     # def status(self, req=None, res=None):
-    def status(self):
-        _id = self._context_info.context_id if not (self._context_info is None) else ""
-        name = self._context_info.name if not (self._context_info is None) else "unknown"
-        description = self._context_info.description if not (self._context_info is None) else ""
-        uptime = (datetime.datetime.now() - self._start_time).total_seconds() * 1000
-        properties = self._context_info.properties if not (self._context_info is None) else ""
+    def status(self) -> str:
+        _id = self.__context_info.context_id if not (self.__context_info is None) else ""
+        name = self.__context_info.name if not (self.__context_info is None) else "unknown"
+        description = self.__context_info.description if not (self.__context_info is None) else ""
+        uptime = (datetime.datetime.now() - self.__start_time).total_seconds() * 1000
+        properties = self.__context_info.properties if not (self.__context_info is None) else ""
 
         components = []
-        if not (self._references2 is None):
-            for locator in self._references2.get_all_locators():
+        if not (self.__references2 is None):
+            for locator in self.__references2.get_all_locators():
                 components.append(locator.__str__())
 
         status = Parameters.from_tuples("id", _id,
                                         "name", name,
                                         "description", description,
-                                        "start_time", StringConverter.to_string(self._start_time),
+                                        "start_time", StringConverter.to_string(self.__start_time),
                                         "current_time", StringConverter.to_string(datetime.datetime.now()),
                                         "uptime", uptime,
                                         "properties", properties,
                                         "components", components
                                         )
         return self.send_result(status)
- 
\ No newline at end of file
