@@ -18,6 +18,7 @@ from pip_services3_commons.validate import ObjectSchema, FilterParamsSchema
 
 from pip_services3_rpc.services import AboutOperations
 from pip_services3_rpc.services import RestService
+from .. import IDummyController, Dummy
 from ..DummySchema import DummySchema
 
 
@@ -25,20 +26,19 @@ class DummyRestService(RestService):
 
     def __init__(self):
         super(DummyRestService, self).__init__()
-        # self._controller = DummyRestOperations()
         self._dependency_resolver.put('controller',
                                       Descriptor("pip-services-dummies", "controller", "default", "*", "*"))
 
-        self._controller = None
+        self._controller: IDummyController = None
         self._number_of_calls = 0
-        self._open_api_content = None
-        self._open_api_file = None
+        self._swagger_content = None
+        self._swagger_path = None
 
     def configure(self, config):
         super().configure(config)
 
-        self._open_api_content = config.get_as_nullable_string("openapi_content")
-        self._open_api_file = config.get_as_nullable_string('openapi_file')
+        self._swagger_content = config.get_as_nullable_string("swagger.content")
+        self._swagger_path = config.get_as_nullable_string('swagger.path')
 
     def set_references(self, references):
         super().set_references(references)
@@ -47,41 +47,61 @@ class DummyRestService(RestService):
     def get_number_of_calls(self) -> int:
         return self._number_of_calls
 
-    def _increment_number_of_calls(self, req=None, res=None):
+    def _increment_number_of_calls(self):
         self._number_of_calls += 1
 
     def __get_page_by_filter(self):
-        return self._controller.get_page_by_filter(
-            bottle.request.query.get('correlation_id'),
+        result = self._controller.get_page_by_filter(
+            self._get_correlation_id(),
             FilterParams(bottle.request.query.dict),
             PagingParams(bottle.request.query.get('skip'),
                          bottle.request.query.get('take'),
                          bottle.request.query.get('total')),
-        ).to_json()
-
-    def __get_one_by_id(self, id):
-        return self._controller.get_one_by_id(
-            bottle.request.query.get('correlation_id'),
-            bottle.request.query.get('id'),
         )
 
+        return self.send_result(result)
+
+    def __get_one_by_id(self, dummy_id):
+        result = self._controller.get_one_by_id(
+            self._get_correlation_id(),
+            dummy_id,
+        )
+        return self.send_result(result)
+
     def __create(self):
-        return self._controller.create(
-            bottle.request.query.get('correlation_id'),
-            json.loads(bottle.request.json).get('body'),
+        data = json.loads(bottle.request.json).get('body')
+        entity = Dummy(**data)
+
+        result = self._controller.create(
+            self._get_correlation_id(),
+            entity,
         )
+        return self.send_created_result(result)
 
     def __update(self):
-        return self._controller.update(
-            bottle.request.query.get('correlation_id'),
-            json.loads(bottle.request.json).get('body'),
+        data = json.loads(bottle.request.json).get('body')
+        entity = Dummy(**data)
+
+        result = self._controller.update(
+            self._get_correlation_id(),
+            entity,
         )
 
-    def __delete_by_id(self, id):
-        return self._controller.delete_by_id(
-            bottle.request.query.get('correlation_id'),
-            bottle.request.query.get('dummy_id'),
+        return self.send_deleted_result(result)
+
+    def __delete_by_id(self, dummy_id):
+        result = self._controller.delete_by_id(
+            self._get_correlation_id(),
+            dummy_id,
         )
+        return self.send_deleted_result(result)
+
+    def __check_correlation_id(self):
+        try:
+            result = self._controller.check_correlation_id(self._get_correlation_id())
+            return self.send_result({'correlation_id': result})
+        except Exception as err:
+            return self.send_error(err)
 
     def register(self):
         self.register_interceptor('/dummies', self._increment_number_of_calls)
@@ -92,8 +112,8 @@ class DummyRestService(RestService):
                             .with_optional_property("total", TypeCode.String)
                             .with_optional_property("body", FilterParamsSchema()), self.__get_page_by_filter)
 
-        self.register_route('get', '/dummies/<id>', ObjectSchema(True)
-                            .with_required_property("id", TypeCode.String),
+        self.register_route('get', '/dummies/<dummy_id>', ObjectSchema(True)
+                            .with_required_property("dummy_id", TypeCode.String),
                             self.__get_one_by_id)
 
         self.register_route('post', '/dummies', ObjectSchema(True)
@@ -104,14 +124,17 @@ class DummyRestService(RestService):
                             .with_required_property("body", DummySchema()),
                             self.__update)
 
-        self.register_route('delete', '/dummies/<id>', ObjectSchema(True)
+        self.register_route('delete', '/dummies/<dummy_id>', ObjectSchema(True)
                             .with_required_property("dummy_id", TypeCode.String),
                             self.__delete_by_id)
 
+        self.register_route("get", "/dummies/check/correlation_id",
+                            ObjectSchema(True), self.__check_correlation_id)
+
         self.register_route('post', '/about', None, AboutOperations().get_about)
 
-        if self._open_api_content:
-            self._register_open_api_spec(self._open_api_content)
+        if self._swagger_content:
+            self._register_open_api_spec(self._swagger_content)
 
-        if self._open_api_file:
-            self._register_open_api_spec_from_file(self._open_api_file)
+        if self._swagger_path:
+            self._register_open_api_spec_from_file(self._swagger_path)
