@@ -8,23 +8,21 @@
     :copyright: Conceptual Vision Consulting LLC 2015-2016, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
-import json
-import time
 
 import requests
 from pip_services3_commons.config import ConfigParams
 from pip_services3_commons.refer import References, Descriptor
-from pip_services3_commons.run import Parameters
 from pip_services3_components.info import ContextInfo
-from pip_services3_rpc.services import StatusRestService
 
+from pip_services3_rpc.services import StatusRestService
 
 rest_config = ConfigParams.from_tuples(
     "connection.protocol", "http",
     'connection.host', 'localhost',
     'connection.port', 3002
 )
- 
+
+
 class TestStatusRestService():
     service = None
 
@@ -37,34 +35,30 @@ class TestStatusRestService():
         contextInfo.name = "Test"
         contextInfo.description = "This is a test container"
 
-        cls.references = References.from_tuples(
+        references = References.from_tuples(
             Descriptor("pip-services", "context-info", "default", "default", "1.0"), contextInfo,
             Descriptor("pip-services-dummies", "service", "http", "default", "1.0"), cls.service
         )
 
-        cls.service.set_references(cls.references)
-
+        cls.service.set_references(references)
 
     def setup_method(self, method):
         self.service.open(None)
 
-
     def teardown_method(self, method):
         self.service.close(None)
- 
+
     def test_status(self):
         result = self.invoke("/status")
 
-        assert None != result.text
+        assert result.text is not None
 
     def invoke(self, route):
-        params = { }
+        params = {}
         route = "http://localhost:3002" + route
         response = None
-        timeout = 10000
-        try:
-            # Call the service
-            response = requests.request('GET', route, params=params,  timeout=timeout)
-            return response 
-        except Exception as ex:
-            return False
\ No newline at end of file
+        timeout = 5
+
+        # Call the service
+        response = requests.request('GET', route, params=params, timeout=timeout)
+        return response
